let's create a CR, when I click on composing idea action in workflow, it should open modal, instead of just link an
  idea folder, let's having following function: the top bar having a selection, create new idea or link an idea. 
	if create new idea, in the modal window it should have a text box to give a name to the idea < 10 words, and the same uiux as create idea which will giving two tab composing idea or upload idea. you should reuse the same capability, so user can compose idea or upload idea within the modal window.
	
	if link to existing idea, then have a dropdown listing all the idea folder and it's file and have a search function just like the idea folder tree. user can select any one of idea as coposed idea.
	
	
	the compose/upload idea action should generate two deliverable
	1. new idea or the idea file linked.
	2. the idea folder workflow-{idea name} from composing idea, if linked idea, just return the root folder name of the idea. for example x-ipe-docs/ideas/abc/bcd/new idea.md, the folder should show in delivarable is abc.
	
	